@@ -21,6 +21,8 @@ def run(
     wandb_project: str = "",
     wandb_entity: str = "",
     wandb_api_key: str = "",
+    use_gpu: bool = False,
+    docker_shm_size: str = "2gb",
     no_additional_container: bool = False,
     use_no_cache: bool = False,
 ) -> None:
@@ -39,6 +41,10 @@ def run(
             "initial_experiments".
         wandb_entity (str, optional): Name of wandb entity. Defaults to "beobench".
         wandb_api_key (str, optional): wandb API key. Defaults to None.
+        use_gpu (bool, optional): whether to use GPU from the host system. Defaults to
+            False.
+        docker_shm_size(str, optional): size of the shared memory available to the
+            container. Defaults to '2gb'."
         no_additional_container (bool, optional): wether not to start another container
             to run experiments in. Defaults to False, which means that another container
             is started to run experiments in.
@@ -59,6 +65,16 @@ def run(
         experiment_def = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(experiment_def)
 
+        # check if all attributes present and replace with default if not
+        if not hasattr(experiment_def, "problem"):
+            experiment_def.problem = beobench.experiment.definitions.default.problem
+        if not hasattr(experiment_def, "method"):
+            experiment_def.method = beobench.experiment.definitions.default.method
+        if not hasattr(experiment_def, "rllib_setup"):
+            experiment_def.rllib_setup = (
+                beobench.experiment.definitions.default.rllib_setup
+            )
+
     if no_additional_container:
 
         # Add wandb callback if sufficient information
@@ -71,11 +87,17 @@ def run(
             )
         else:
             callbacks = []
+
+        # change RLlib setup if GPU used
+        rllib_setup = experiment_def.rllib_setup
+        if use_gpu:
+            rllib_setup["rllib_experiment_config"]["config"]["num_gpus"] = 1
+
         # run experiment in ray tune
         run_in_tune(
             problem_def=experiment_def.problem,
             method_def=experiment_def.method,
-            rllib_setup=experiment_def.rllib_setup,
+            rllib_setup=rllib_setup,
             rllib_callbacks=callbacks,
         )
     else:
@@ -91,7 +113,6 @@ def run(
             build_context=experiment_def.problem["problem_library"],
             use_no_cache=use_no_cache,
         )
-        beobench.experiment.containers.create_docker_network("beobench-net")
 
         # define docker arguments/options/flags
         unique_id = uuid.uuid4().hex[:6]
@@ -106,6 +127,28 @@ def run(
                 f"{exp_file_abs}:{exp_file_on_docker}:ro",
             ]
 
+        # enable docker-from-docker access only for built-in boptest integration.
+        if experiment_def.problem["problem_library"] == "boptest":
+
+            # Create docker network (only useful if starting other containers)
+            beobench.experiment.containers.create_docker_network("beobench-net")
+
+            docker_flags += [
+                # enable access to docker-from-docker
+                "-v",
+                "/var/run/docker.sock:/var/run/docker.sock",
+                # network allows access to BOPTEST API in other containers
+                "--network",
+                "beobench-net",
+            ]
+
+        # enabling GPU access in docker container
+        if use_gpu:
+            docker_flags += [
+                # add all available GPUs
+                "--gpus=all",
+            ]
+
         # define flags for beobench scheduler call inside experiment container
         beobench_flags = []
         if experiment_file:
@@ -114,6 +157,8 @@ def run(
             beobench_flags.append(f"--wandb-project={wandb_project}")
         if wandb_entity:
             beobench_flags.append(f"--wandb-entity={wandb_entity}")
+        if use_gpu:
+            beobench_flags.append("--use-gpu")
         beobench_flag_str = " ".join(beobench_flags)
 
         # if no wandb API key is given try to get it from env
@@ -124,21 +169,13 @@ def run(
         args = [
             "docker",
             "run",
-            # the mounted socket allows access to docker
-            "-v",
-            "/var/run/docker.sock:/var/run/docker.sock",
             # mount experiment data dir
             "-v",
             f"{local_dir_abs}:/root/ray_results",
             # automatically remove container when stopped/exited
             "--rm",
-            # network allows access to BOPTEST API in other containers
-            "--network",
-            "beobench-net",
             # add more memory
-            "--shm-size=20.48gb",
-            # add available GPUs,
-            "--gpus=all",
+            f"--shm-size={docker_shm_size}",
             "--name",
             container_name,
             *docker_flags,
@@ -183,6 +220,16 @@ def run(
     default="",
     help="Weights and biases API key.",
 )
+@click.option(
+    "--use-gpu",
+    is_flag=True,
+    help="Whether to use GPUs from the host system in experiment container.",
+)
+@click.option(
+    "--docker-shm-size",
+    default="2gb",
+    help="Size of shared memory available to experiment container.",
+)
 @click.option(
     "--no-additional-container",
     is_flag=True,
@@ -199,6 +246,8 @@ def run_command(
     wandb_project: str,
     wandb_entity: str,
     wandb_api_key: str,
+    use_gpu: bool,
+    docker_shm_size: str,
     no_additional_container: bool,
     use_no_cache: bool,
 ) -> None:
@@ -216,6 +265,8 @@ def run_command(
         wandb_project=wandb_project,
         wandb_entity=wandb_entity,
         wandb_api_key=wandb_api_key,
+        use_gpu=use_gpu,
+        docker_shm_size=docker_shm_size,
         no_additional_container=no_additional_container,
         use_no_cache=use_no_cache,
     )
